/*
 * #%L
 * OME-XERCES C++ library for working with Xerces C++.
 * %%
 * Copyright © 2016 Open Microscopy Environment:
 *   - Massachusetts Institute of Technology
 *   - National Institutes of Health
 *   - University of Dundee
 *   - Board of Regents of the University of Wisconsin-Madison
 *   - Glencoe Software, Inc.
 * %%
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright notice,
 *    this list of conditions and the following disclaimer in the documentation
 *    and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDERS OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 *
 * The views and conclusions contained in the software and documentation are
 * those of the authors and should not be interpreted as representing official
 * policies, either expressed or implied, of any organization.
 * #L%
 */

#include <cstring>
#include <stdexcept>

#include <ome/common/xml/String.h>

#include <xercesc/util/TransService.hpp>

namespace ome
{
  namespace common
  {
    namespace xml
    {

      char *
      String::transcode(const XMLCh *str)
      {
        if (str)
          {
            if (xercesc::XMLString::stringLen(str) == 0)
              return xercesc::XMLString::replicate("");

            try
              {
                xercesc::TranscodeToStr tc(str, "UTF-8");
                return reinterpret_cast<char *>(tc.adopt());
              }
            catch (const xercesc::XMLException&)
              {
                throw std::runtime_error("XML UTF-16 to UTF-8 transcoding failure");
              }
          }

      return 0;
    }

      XMLCh *
      String::transcode(const char *str)
      {
        if (str)
          {
            if (strlen(str) == 0)
              {
                const XMLCh src[] = { 0x0 };
                return xercesc::XMLString::replicate(src);
              }

            try
              {
                xercesc::TranscodeFromStr tc(reinterpret_cast<const XMLByte *>(str), std::strlen(str), "UTF-8");
                return tc.adopt();
              }
            catch (const xercesc::XMLException&)
              {
                throw std::runtime_error("XML UTF-8 to UTF-16 transcoding failure");
              }
          }

        return 0;
      }

    }
  }
}
